==> 24.1.5.tar.gz: dbeaver-24.1.5/plugins/org.jkiss.dbeaver.model.event/src/org/jkiss/dbeaver/model/websocket/event/WSProjectUpdateEvent.java <==
/*
 * DBeaver - Universal Database Manager
 * Copyright (C) 2010-2024 DBeaver Corp and others
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jkiss.dbeaver.model.websocket.event;

import org.jkiss.code.NotNull;
import org.jkiss.code.Nullable;

public class WSProjectUpdateEvent extends WSAbstractEvent implements WSProjectEvent {

    @NotNull
    protected final String projectId;

    public WSProjectUpdateEvent(
        @NotNull WSEventType eventType,
        @Nullable String sessionId,
        @Nullable String userId,
        @NotNull String projectId
    ) {
        super(eventType, sessionId, userId);
        this.projectId = projectId;
    }

    public static WSProjectUpdateEvent create(
        @Nullable String sessionId,
        @Nullable String userId,
        @NotNull String projectId
    ) {
        return new WSProjectUpdateEvent(
            WSEventType.RM_PROJECT_ADDED,
            sessionId,
            userId,
            projectId
        );
    }

    public static WSProjectUpdateEvent delete(
        @Nullable String sessionId,
        @Nullable String userId,
        @NotNull String projectId
    ) {
        return new WSProjectUpdateEvent(
            WSEventType.RM_PROJECT_REMOVED,
            sessionId,
            userId,
            projectId
        );
    }

    @NotNull
    @Override
    public String getProjectId() {
        return projectId;
    }
}

==> 24.3.2.tar.gz: dbeaver-24.3.2/plugins/org.jkiss.dbeaver.model.event/src/org/jkiss/dbeaver/model/websocket/event/WSProjectUpdateEvent.java <==
/*
 * DBeaver - Universal Database Manager
 * Copyright (C) 2010-2024 DBeaver Corp and others
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jkiss.dbeaver.model.websocket.event;

import org.jkiss.code.NotNull;
import org.jkiss.code.Nullable;
import org.jkiss.dbeaver.model.websocket.WSConstants;

public class WSProjectUpdateEvent extends WSAbstractEvent implements WSProjectEvent {
    public static final String ADDED = "cb_rm_project_added";
    public static final String REMOVED = "cb_rm_project_removed";

    @NotNull
    protected final String projectId;

    public WSProjectUpdateEvent(
        @NotNull String eventId,
        @Nullable String sessionId,
        @Nullable String userId,
        @NotNull String projectId
    ) {
        super(eventId, WSConstants.TOPIC_PROJECTS, sessionId, userId);
        this.projectId = projectId;
    }

    public static WSProjectUpdateEvent create(
        @Nullable String sessionId,
        @Nullable String userId,
        @NotNull String projectId
    ) {
        return new WSProjectUpdateEvent(
            ADDED,
            sessionId,
            userId,
            projectId
        );
    }

    public static WSProjectUpdateEvent delete(
        @Nullable String sessionId,
        @Nullable String userId,
        @NotNull String projectId
    ) {
        return new WSProjectUpdateEvent(
            REMOVED,
            sessionId,
            userId,
            projectId
        );
    }

    @NotNull
    @Override
    public String getProjectId() {
        return projectId;
    }
}
